@@ -1,5 +1,4 @@
 from mate import MateModule, command, add_plugins
-from mate.utils.colors import magenta
 from mate.config import mate_config
 
 
@@ -13,26 +12,26 @@ class MateShow(MateModule):
     def show_all(self):
         """Shows everything."""
         results = {}
-        results["Version:"] = str(mate_config.mate_version)
-        results["Author:"] = str(mate_config.mate_author)
-        results["Project Directory:"] = str(mate_config.project_dir)
-        results["Output Directory:"] = str(mate_config.output_dir)
+        results["Version"] = str(mate_config.mate_version)
+        results["Author"] = str(mate_config.mate_author)
+        results["Project Directory"] = str(mate_config.project_dir)
+        results["Output Directory"] = str(mate_config.output_dir)
         return results
 
     @command(option="mate")
     def show_mate(self):
         """Shows mate's details."""
         results = {}
-        results["Version:"] = str(mate_config.mate_version)
-        results["Author:"] = str(mate_config.mate_author)
+        results["Version"] = str(mate_config.mate_version)
+        results["Author"] = str(mate_config.mate_author)
         return results
 
     @command(option="context")
     def show_context(self):
         """Shows current running context."""
         results = {}
-        results["Project Directory:"] = str(mate_config.project_dir)
-        results["Output Directory:"] = str(mate_config.output_dir)
+        results["Project Directory"] = str(mate_config.project_dir)
+        results["Output Directory"] = str(mate_config.output_dir)
         return results
 
 
